src/hg/inc/refSeqStatus.h 1.2

1.2 2009/07/04 07:14:19 markd
added some .h files for genbank tables
Index: src/hg/inc/refSeqStatus.h
===================================================================
RCS file: /projects/compbio/cvsroot/kent/src/hg/inc/refSeqStatus.h,v
retrieving revision 1.1
retrieving revision 1.2
diff -b -B -U 4 -r1.1 -r1.2
--- src/hg/inc/refSeqStatus.h	19 Jun 2002 21:23:24 -0000	1.1
+++ src/hg/inc/refSeqStatus.h	4 Jul 2009 07:14:19 -0000	1.2
@@ -4,14 +4,45 @@
 
 #ifndef REFSEQSTATUS_H
 #define REFSEQSTATUS_H
 
+#define REFSEQSTATUS_NUM_COLS 3
+
+enum refSeqStatusStatus
+    {
+    refSeqStatusUnknown = 0,
+    refSeqStatusReviewed = 1,
+    refSeqStatusValidated = 2,
+    refSeqStatusProvisional = 3,
+    refSeqStatusPredicted = 4,
+    refSeqStatusInferred = 5,
+    };
+enum refSeqStatusMol
+    {
+    refSeqStatusDNA = 0,
+    refSeqStatusRNA = 1,
+    refSeqStatusDs_RNA = 2,
+    refSeqStatusDs_mRNA = 3,
+    refSeqStatusDs_rRNA = 4,
+    refSeqStatusMRNA = 5,
+    refSeqStatusMs_DNA = 6,
+    refSeqStatusMs_RNA = 7,
+    refSeqStatusRRNA = 8,
+    refSeqStatusScRNA = 9,
+    refSeqStatusSnRNA = 10,
+    refSeqStatusSnoRNA = 11,
+    refSeqStatusSs_DNA = 12,
+    refSeqStatusSs_RNA = 13,
+    refSeqStatusSs_snoRNA = 14,
+    refSeqStatusTRNA = 15,
+    };
 struct refSeqStatus
 /* RefSeq Gene Status. */
     {
     struct refSeqStatus *next;  /* Next in singly linked list. */
     char *mrnaAcc;	/* RefSeq gene accession name */
-    char *status;	/* Status (Reviewed, Provisional, Predicted) */
+    enum refSeqStatusStatus status;	/* Status of RefSeq */
+    enum refSeqStatusMol mol;	/* molecule type */
     };
 
 void refSeqStatusStaticLoad(char **row, struct refSeqStatus *ret);
 /* Load a row from refSeqStatus table into ret.  The contents of ret will
@@ -21,14 +52,17 @@
 /* Load a refSeqStatus from row fetched with select * from refSeqStatus
  * from database.  Dispose of this with refSeqStatusFree(). */
 
 struct refSeqStatus *refSeqStatusLoadAll(char *fileName);
-/* Load all refSeqStatus from a tab-separated file.
+/* Load all refSeqStatus from whitespace-separated file.
+ * Dispose of this with refSeqStatusFreeList(). */
+
+struct refSeqStatus *refSeqStatusLoadAllByChar(char *fileName, char chopper);
+/* Load all refSeqStatus from chopper separated file.
  * Dispose of this with refSeqStatusFreeList(). */
 
-struct refSeqStatus *refSeqStatusLoadWhere(struct sqlConnection *conn, char *table, char *where);
-/* Load all refSeqStatus from table that satisfy where clause. The
- * where clause may be NULL in which case whole table is loaded
+#define refSeqStatusLoadAllByTab(a) refSeqStatusLoadAllByChar(a, '\t');
+/* Load all refSeqStatus from tab separated file.
  * Dispose of this with refSeqStatusFreeList(). */
 
 struct refSeqStatus *refSeqStatusCommaIn(char **pS, struct refSeqStatus *ret);
 /* Create a refSeqStatus out of a comma separated string. 
@@ -50,6 +84,8 @@
 
 #define refSeqStatusCommaOut(el,f) refSeqStatusOutput(el,f,',',',');
 /* Print out refSeqStatus as a comma separated list including final comma. */
 
+/* -------------------------------- End autoSql Generated Code -------------------------------- */
+
 #endif /* REFSEQSTATUS_H */